@@ -60,30 +60,37 @@ class Engine:
         while not engine.completed:
           state = engine.play_next()
 
-    This plays a turn for each player, one after another, until the
-    game is complete.  Other, more fine-grained methods exist if you
-    need to structure game play differently for your purposes (for
-    instance, to train a machine learning model).
+    This synchronously plays a turn for each player, one after another, until
+    the game is complete.  Other, more fine-grained methods exist if you need
+    to structure game play differently for your purposes (for instance, to
+    train a machine learning model or to play the game in an asynchronous
+    event-driven environment).
 
     Attributes:
         mode(GameMode): The game mode
         characters(List[Character]): Characters playing the game
+        first(PlayerColor): The first player, chosen randomly by default
     """
 
     mode = attr.ib(type=GameMode)
     characters = attr.ib(type=List[Character])
+    first = attr.ib(type=PlayerColor)
     _game = attr.ib(init=False, type=Game)
     _queue = attr.ib(init=False, type=CircularQueue[PlayerColor])
     _rules = attr.ib(init=False, type=Rules)
     _map = attr.ib(init=False, type=Dict[PlayerColor, Character])
 
+    @first.default
+    def _default_first(self) -> PlayerColor:
+        return random.choice(list(PlayerColor)[: len(self.characters)])
+
     @_game.default
     def _default_game(self) -> Game:
         return Game(playercount=len(self.characters))
 
     @_queue.default
     def _default_queue(self) -> CircularQueue[PlayerColor]:
-        return CircularQueue(list(PlayerColor)[: len(self.characters)])
+        return CircularQueue(list(PlayerColor)[: len(self.characters)], first=self.first)
 
     @_rules.default
     def _default_rules(self) -> Rules:
@@ -128,6 +135,14 @@ class Engine:
         """Whether the game is completed."""
         return self._game.completed
 
+    @property
+    def colors(self) -> Dict[PlayerColor, Character]:
+        return self._map.copy()
+
+    def winner(self) -> Optional[Tuple[Character, Player]]:
+        """Return the winner of the game, as a tuple of (Character, Player)"""
+        return (self._map[self._game.winner.color], self._game.winner) if self.completed else None  # type: ignore
+
     def reset(self) -> Game:
         """Reset game state."""
         self._game = self._default_game()
@@ -143,9 +158,18 @@ class Engine:
         self._rules.start_game(self._game)
         return self._game
 
+    def next_turn(self) -> Tuple[PlayerColor, Character]:
+        """
+        Get the color and character for the next turn
+        This will give you a different player each time you call it.
+        """
+        color = self._queue.next()
+        character = self._map[color]
+        return color, character
+
     def play_next(self) -> Game:
         """
-        Play the next turn of the game, returning initial game state.
+        Play the next turn of the game, returning game state as of the end of the turn.
 
         Returns:
             Game: Current state of the game.
@@ -155,8 +179,7 @@ class Engine:
 
         saved = self._game.copy()
         try:
-            color = self._queue.next()
-            character = self._map[color]
+            color, character = self.next_turn()
 
             done = False
             while not done:
